# libmonty - Python libraries

Python libraries

### License
[Mozilla Public License 2.0](https://spdx.org/licenses/MPL-2.0.html)

## Acknowledgements

- Python section in global .gitignore taken from [github/gitignore](https://github.com/github/gitignore) under the [CC0-1.0 License](https://choosealicense.com/licenses/cc0-1.0/).
- Thanks to [Guido van Rossum](https://gvanrossum.github.io/), the [Python Software Foundation](https://www.python.org/psf/), and all contributors for the [Python](https://www.python.org/) programming language
